==> easyapi-0.7.5.9.1-sources.jar: cn/easyutil/easyapi/filter/ApiExtra.java <==
package cn.easyutil.easyapi.filter;

import cn.easyutil.easyapi.javadoc.reader.ClassComment;
import cn.easyutil.easyapi.javadoc.reader.FieldComment;
import cn.easyutil.easyapi.javadoc.reader.MethodComment;

import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Parameter;
import java.lang.reflect.Type;

/**
 * 额外信息
 */
public class ApiExtra {

    //控制器类
    private Class controllerClass;

    //控制器源码信息
    private ClassComment controllerComment;

    //接口方法
    private Method method;

    //接口源码信息
    private MethodComment methodComment;

    //参数类
    private Parameter parameter;

    //返回参数
    private Type returnType;

    //当前解析的参数类型
    private Class modelClass;

    //当前解析的参数字段
    private Field modelField;

    //字段源码信息
    private FieldComment fieldComment;

    public Class getControllerClass() {
        return controllerClass;
    }

    public void setControllerClass(Class controllerClass) {
        this.controllerClass = controllerClass;
    }

    public ClassComment getControllerComment() {
        return controllerComment;
    }

    public void setControllerComment(ClassComment controllerComment) {
        this.controllerComment = controllerComment;
    }

    public Method getMethod() {
        return method;
    }

    public void setMethod(Method method) {
        this.method = method;
    }

    public MethodComment getMethodComment() {
        return methodComment;
    }

    public void setMethodComment(MethodComment methodComment) {
        this.methodComment = methodComment;
    }

    public Parameter getParameter() {
        return parameter;
    }

    public void setParameter(Parameter parameter) {
        this.parameter = parameter;
    }

    public Type getReturnType() {
        return returnType;
    }

    public void setReturnType(Type returnType) {
        this.returnType = returnType;
    }

    public Field getModelField() {
        return modelField;
    }

    public void setModelField(Field modelField) {
        this.modelField = modelField;
    }

    public FieldComment getFieldComment() {
        return fieldComment;
    }

    public void setFieldComment(FieldComment fieldComment) {
        this.fieldComment = fieldComment;
    }

    public Class getModelClass() {
        return modelClass;
    }

    public void setModelClass(Class modelClass) {
        this.modelClass = modelClass;
    }
}

==> easyapi-0.7.6.1-sources.jar: cn/easyutil/easyapi/filter/ApiExtra.java <==
package cn.easyutil.easyapi.filter;

import cn.easyutil.easyapi.entity.db.doc.DBModuleControllerEntity;
import cn.easyutil.easyapi.entity.db.doc.DBModuleInterfaceEntity;
import cn.easyutil.easyapi.javadoc.reader.ClassComment;
import cn.easyutil.easyapi.javadoc.reader.FieldComment;
import cn.easyutil.easyapi.javadoc.reader.MethodComment;

import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Parameter;
import java.lang.reflect.Type;

/**
 * 额外信息
 */
public class ApiExtra {

    //控制器类
    private Class controllerClass;

    //控制器源码信息
    private ClassComment controllerComment;

    //数据库存储的控制器信息
    private DBModuleControllerEntity dbController;

    //接口方法
    private Method method;

    //接口源码信息
    private MethodComment methodComment;

    //数据库存储的接口信息
    private DBModuleInterfaceEntity dbInterface;

    //参数类
    private Parameter parameter;

    //返回参数
    private Type returnType;

    //当前解析的参数类型
    private Class modelClass;

    //当前解析的参数字段
    private Field modelField;

    //字段源码信息
    private FieldComment fieldComment;

    public Class getControllerClass() {
        return controllerClass;
    }

    public void setControllerClass(Class controllerClass) {
        this.controllerClass = controllerClass;
    }

    public ClassComment getControllerComment() {
        return controllerComment;
    }

    public void setControllerComment(ClassComment controllerComment) {
        this.controllerComment = controllerComment;
    }

    public Method getMethod() {
        return method;
    }

    public void setMethod(Method method) {
        this.method = method;
    }

    public MethodComment getMethodComment() {
        return methodComment;
    }

    public void setMethodComment(MethodComment methodComment) {
        this.methodComment = methodComment;
    }

    public Parameter getParameter() {
        return parameter;
    }

    public void setParameter(Parameter parameter) {
        this.parameter = parameter;
    }

    public Type getReturnType() {
        return returnType;
    }

    public void setReturnType(Type returnType) {
        this.returnType = returnType;
    }

    public Field getModelField() {
        return modelField;
    }

    public void setModelField(Field modelField) {
        this.modelField = modelField;
    }

    public FieldComment getFieldComment() {
        return fieldComment;
    }

    public void setFieldComment(FieldComment fieldComment) {
        this.fieldComment = fieldComment;
    }

    public Class getModelClass() {
        return modelClass;
    }

    public void setModelClass(Class modelClass) {
        this.modelClass = modelClass;
    }

    public DBModuleControllerEntity getDbController() {
        return dbController;
    }

    public void setDbController(DBModuleControllerEntity dbController) {
        this.dbController = dbController;
    }

    public DBModuleInterfaceEntity getDbInterface() {
        return dbInterface;
    }

    public void setDbInterface(DBModuleInterfaceEntity dbInterface) {
        this.dbInterface = dbInterface;
    }
}
